The objective function is the negative of log likelihood function.
free.loglikelihood(para, X, Y.col, Y.c, ziMatrix)Vector of optimized parameters with length p+q+1, where p is the number of covariates for count model (e.g., beta-binomial), q is the number of covariates for zero model. The first p elements are betas which are the effects/coefficients for the count model. The (p+1)'th element is the logit of the overdispersion parameter. The last q elements are etas which are the effects/coefficients for the zero model.
The design matrix (n by p, p is the number of covariates) for the count model (e.g., beta-binomial), and intercept is included.
Vector of counts corresponding to an OTU, with length n.
Vector of library size with length n.
The design matrix (n by q) for the zero model, and intercept is included.