Learn R Programming

ZIBBSeqDiscovery (version 1.0)

kostic.x: Data set for ZIBBSeqDiscovery

Description

Data set for ZIBBSeqDiscovery. The data set kostic.x is a count matrix with 2505 OTUs and 185 samples randomly selected from a real microbiome data set kostic.

Usage

data("kostic.x")

Arguments

References

Kostic, A. D., Gevers, D., Pedamallu, C. S., Michaud, M., Duke, F., Earl, A. M., Ojesina, A. I., Jung, J., Bass, A. J., Tabernero, J., et al. (2012). Genomic analysis identifies association of fusobacterium with colorectal carcinoma. Genome research 22, 292-298.

Examples

Run this code
# NOT RUN {
## load the data
data(kostic.x)
dim(kostic.x)
# }

Run the code above in your browser using DataLab